==> pari-2.2.3.a.tgz: include/pari/parierr.h <==
/* $Id: parierr.h,v 1.11 2002/05/07 01:08:40 karim Exp $

Copyright (C) 2000  The PARI group.

This file is part of the PARI/GP package.

PARI/GP is free software; you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation. It is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY WHATSOEVER.

Check the License for details. You should have received a copy of it, along
with the package; see the file 'COPYING'. If not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */

enum {
  caracer1, caseer, caseer2, member, nparamer1,
  paramer1, varer1, obsoler, openfiler, talker2,

/* NO CONTEXT now */

  talker, flagerr, warner, warnprec, warnfile,
  accurer, bugparier, impl, archer, warnmem, precer,

  siginter, typeer, consister,

/* mp.s ou mp.c */

  affer1, affer2, affer3, affer4, affer5,
  shier1, shier2, truer1, adder1,
  
  adder2, adder3, adder4, adder5, muler1,
  muler2, muler3, muler4, muler5, muler6,
  diver1, diver2, diver3, diver4, diver5,
  diver6, diver7, diver8, diver9, diver10,
  diver11, diver12, divzer1, dvmer1, moder1,
  
  reser1, arier1, arier2, errpile, errlg,
  errlgef, errexpo, errvalp, rtodber,

/* alglin.c */

  concater, matinv1, mattype1, suppler2,

/* anal.c   */

  valencer1, breaker,

/* arith.c  */

  arither1, arither2, facter, hiler1, funder2,
  generer, primer1,invmoder,

/* base.c   */
  polrationer, constpoler, notpoler, redpoler, zeropoler,
  idealer1, idealer2,

/* bibli.c  */

  changer1, intger2, lllger3, lllger4,

/* elliptic.c */

  elliper1, heller1,

/* gen.c */
  operi, operf, gdiver2, inter2, overwriter,

/* init.c */

  memer, gerper,

/* plot.c */

  ploter4, ploter5,

/* polarit.c */

  rootper1, rootper2, rootper4,

/* trans.c */

  infprecer, negexper, sqrter5, sqrter6, gamer2,
  thetaer1,

/* PAS D'ERREUR */

  noer
};

==> pari-2.2.4.a.tgz: include/pari/parierr.h <==
/* $Id: parierr.h,v 1.13 2002/09/12 18:37:02 karim Exp $

Copyright (C) 2000  The PARI group.

This file is part of the PARI/GP package.

PARI/GP is free software; you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation. It is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY WHATSOEVER.

Check the License for details. You should have received a copy of it, along
with the package; see the file 'COPYING'. If not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */

enum {
  caracer1, caseer, caseer2, member, nparamer1,
  paramer1, varer1, obsoler, openfiler, talker2,

/* NO CONTEXT now */

  talker, flagerr, warner, warnprec, warnfile,
  accurer, bugparier, impl, archer, warnmem, precer,

  siginter, typeer, consister, user,

/* mp.s ou mp.c */

  affer1, affer2, affer3, affer4, affer5,
  shier1, shier2, truer1, adder1,
  
  adder2, adder3, adder4, adder5, muler1,
  muler2, muler3, muler4, muler5, muler6,
  diver1, diver2, diver3, diver4, diver5,
  diver6, diver7, diver8, diver9, diver10,
  diver11, diver12, divzer1, dvmer1, moder1,
  
  reser1, arier1, arier2, errpile, errlg,
  errlgef, errexpo, errvalp, rtodber,

/* alglin.c */

  concater, matinv1, mattype1, suppler2,

/* anal.c   */

  valencer1, breaker,

/* arith.c  */

  arither1, arither2, facter, hiler1, funder2,
  generer, primer1,invmoder,

/* base.c   */
  polrationer, constpoler, notpoler, redpoler, zeropoler,
  idealer1, idealer2,

/* bibli.c  */

  changer1, intger2, lllger3, lllger4,

/* elliptic.c */

  elliper1, heller1,

/* gen.c */
  operi, operf, gdiver, inter2, overwriter,

/* init.c */

  memer, gerper,

/* plot.c */

  ploter4, ploter5,

/* polarit.c */

  rootper1, rootper2, rootper4,

/* trans.c */

  infprecer, negexper, sqrter5, sqrter6, gamer2,
  thetaer1,

/* PAS D'ERREUR */

  noer
};
